Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(168)

Unified Diff: content/renderer/render_view_impl.h

Issue 8934011: Rename IntentsHost -> WebIntentsDispatcher and IntentsDispatcher -> WebIntentsHost. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src
Patch Set: Created 9 years ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
Index: content/renderer/render_view_impl.h
diff --git a/content/renderer/render_view_impl.h b/content/renderer/render_view_impl.h
index b4554cb458117816ef77ffa3d7e94b1bfd6af251..d7dca4fbf9ab1bcdbe005bec54d9c326bb44fbf9 100644
--- a/content/renderer/render_view_impl.h
+++ b/content/renderer/render_view_impl.h
@@ -62,7 +62,6 @@ class DevToolsAgent;
class ExternalPopupMenu;
class GeolocationDispatcher;
class GURL;
-class IntentsDispatcher;
class JavaBridgeDispatcher;
class LoadProgressTracker;
class MediaStreamImpl;
@@ -77,6 +76,7 @@ struct ViewMsg_Navigate_Params;
struct ViewMsg_StopFinding_Params;
struct ViewMsg_SwapOut_Params;
struct WebDropData;
+class WebIntentsHost;
class WebPluginDelegateProxy;
class WebUIBindings;
@@ -1125,8 +1125,8 @@ class RenderViewImpl : public RenderWidget,
// The geolocation dispatcher attached to this view, lazily initialized.
GeolocationDispatcher* geolocation_dispatcher_;
- // The intents dispatcher attached to this view. Not lazily initialized.
- IntentsDispatcher* intents_dispatcher_;
+ // The intents host attached to this view. Not lazily initialized.
+ WebIntentsHost* intents_host_;
// The speech dispatcher attached to this view, lazily initialized.
SpeechInputDispatcher* speech_input_dispatcher_;

Powered by Google App Engine
This is Rietveld 408576698